
# q-expansion of newform 2523.2.a.r, downloaded from the LMFDB on 13 January 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2523
weight = 2
poly_data = [-8, -36, 84, 21, -90, 6, 33, -6, -4, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[6, 15, -40, -2, 25, -4, -4, 1, 0], 2], [[0, -8, -15, 40, 2, -25, 4, 4, -1], 2], [[-4, 6, 17, -40, -2, 25, -4, -4, 1], 2], [[4, 16, -69, 34, 44, -31, -4, 6, -1], 2], [[-20, -84, 169, 2, -106, 33, 14, -8, 1], 4], [[12, 128, -147, -94, 106, 17, -22, 0, 1], 4], [[2, -8, 40, -36, -23, 28, 0, -5, 1], 1]]

hecke_ring_character_values = None
aps_data = [[1, -1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -1, 0], [0, 0, 0, 1, 1, 0, -1, -1, 0], [0, 0, 0, 0, 1, -1, 2, 0, 0], [0, 0, 1, 1, 1, 2, 0, 0, 0], [-1, 1, 1, 2, 1, 0, -2, -1, 0], [0, 2, 0, 2, 0, 1, -2, -2, 0], [0, 1, 0, 0, -1, -2, 2, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 2, 2, 2, 1, 1, -1, -1, 0], [2, 0, -1, 1, 0, 2, -2, 0, 2], [4, -1, 1, -2, -1, 2, 1, -1, 0], [4, -1, 2, 0, -1, -1, 1, -1, 0], [-2, 0, -2, 0, 1, -1, -1, -1, -1], [1, -2, -1, -3, -3, -1, 1, 2, -1], [-2, 1, -2, 1, -1, -1, 1, -1, -2], [3, 1, -1, 0, -2, 2, 1, 0, 0], [0, 3, 4, 0, 2, -1, 2, 0, 0], [0, -2, 2, -1, -1, 1, 4, 0, 2], [1, -2, -1, 0, 1, 1, 0, -1, -3], [-2, 2, -2, -2, 0, -3, 0, 2, -1], [4, -1, 0, -3, 0, 0, 3, -1, -2], [4, 0, 2, 0, 0, 3, 7, 0, -1], [4, -1, 5, 0, 1, 3, 2, -2, 0], [2, 0, 0, -2, 1, 0, 1, 0, 1], [2, 3, 0, -1, 0, 1, 3, -1, 0], [-4, -3, 0, 0, 3, 0, 0, 0, 0], [-2, -5, -1, 1, -1, 1, -4, 2, 0], [-4, 1, -2, 1, 1, 3, -3, 2, 2], [4, -5, -4, -4, -2, -4, 5, 1, -3], [0, 1, -4, 1, -1, -1, 3, -1, 0], [6, 0, -6, -3, -3, 0, -2, -1, 1], [4, 1, 4, -3, 1, -6, 8, 4, 0], [-5, 0, -3, -2, 2, -1, -3, -2, -2], [12, 0, 0, -2, -1, 1, 2, 2, 2], [8, 0, 2, -7, -1, -7, 9, 0, -4], [2, -3, -6, -3, 2, 1, -4, -2, 0], [-4, 1, 0, 5, -1, 1, 3, -1, -1], [-3, 3, 1, -1, -1, 2, 1, 0, 2], [-4, -1, -4, -4, 0, -1, 1, -1, 1], [4, 3, 10, 1, 1, -2, 4, -1, -2], [-4, 1, 2, 0, 2, -2, -5, -1, 1], [6, -3, -2, -2, -4, 1, 1, 2, -2], [-2, 1, 2, 1, -1, 1, 3, -2, 1], [12, -1, -2, 0, 2, -5, 2, 0, -1], [2, -1, 6, -3, 1, -5, 9, 1, -4], [-4, 9, 2, 3, -3, 0, -1, 3, 4], [-12, 3, -4, 6, 2, 4, -14, -4, 1], [7, -3, 1, 1, 0, -3, -6, -5, -6], [-12, -2, -12, 2, -2, 4, -8, 5, 2], [-6, -1, 2, 2, 7, -4, -2, -4, -1], [11, -2, -1, -2, -3, -1, -4, -5, -2], [-4, 0, 10, 6, 4, -1, 2, -2, -3], [0, 4, 3, 2, -2, 1, 8, 0, 5], [6, -1, 0, 4, -1, 7, 1, -3, 0], [10, 2, 6, -2, -3, -2, 14, 7, 4], [0, -4, 4, -3, 6, -5, 0, -2, -3], [-13, 6, -7, 2, -3, 2, -2, 1, 1], [-4, -2, 1, 1, -2, 8, -3, -1, -1], [-2, 1, -2, 1, 6, 1, -9, -3, -1], [0, 1, 1, -4, 1, 0, -2, 2, 1], [2, -2, -2, 2, -5, 1, 4, 6, 2], [-4, 0, 2, 4, 8, 4, -5, -3, -4], [5, 0, 5, -1, -1, -1, 5, -4, -3], [1, -4, -5, 0, 1, -2, -5, -4, -8], [-10, 2, -8, 3, 5, -2, 0, -2, 0], [14, -1, 3, -6, -3, 0, 7, 3, 2], [-20, 1, -4, 6, 1, 2, -11, 1, 1], [-5, 7, 1, 0, -3, 2, -9, 0, 1], [-2, -2, -3, 3, 4, 5, 1, -3, -6], [0, 4, 6, 1, -1, 2, 3, 5, 5], [10, 0, 10, -6, -1, -2, 15, 7, 5], [-2, 1, 0, 1, -1, 1, -5, -2, 0], [0, -3, 2, -1, -1, -4, -1, 7, 1], [6, 3, 2, 10, 6, 0, -3, -5, 1], [3, 0, -1, -5, 2, -5, 0, 9, 0], [7, -2, 3, -6, -1, -4, 11, -4, 0], [4, -3, 11, 9, 7, 4, 4, -2, 2], [-4, 0, 0, 3, 2, 5, 1, 0, 9], [0, -4, -2, -1, -1, -1, -4, -2, -7], [2, 5, 2, 4, 0, 1, -6, 4, 1], [2, -2, -2, -1, 4, 2, -9, -1, -4], [0, -1, -2, 1, -1, 3, 1, 1, 1], [14, 2, 2, 0, -6, 5, -6, 0, -1], [12, 0, 4, 6, 7, 2, 2, -2, -1], [-13, -7, -11, -1, 0, -2, -5, -2, -1], [-4, 3, 4, -7, -3, 2, -9, 2, 3], [2, -3, 10, 3, 9, -7, 5, -3, -2], [-2, 2, 2, 2, 2, -7, 5, 7, 1], [8, -1, 4, 4, 4, 4, -8, 0, 2], [-4, -5, -16, -11, -8, 4, -9, 5, -3], [2, -6, 10, 2, 6, 2, -3, -3, 0], [-4, 4, -2, 2, -3, -3, 2, 8, 0], [6, -4, 6, -3, -10, 0, 9, -1, -4], [-8, -4, -6, 1, -1, -1, -6, 6, 1], [-10, -6, -1, 2, 2, 9, -9, 1, 5], [-6, -5, 2, -6, 0, -3, 2, 5, 0], [-2, 2, 4, 5, 4, -1, 4, 6, 1], [12, -1, -7, 10, 1, 5, -7, -5, 3], [6, 2, 6, -1, -3, -1, 11, 5, -2], [-8, -15, -13, 0, -1, 2, -1, 1, -2], [-4, 0, -4, -2, -1, -8, -4, -4, -4], [-2, -2, -1, 0, -3, 1, 5, -3, -6], [2, -9, 6, -1, 4, -1, 0, -2, -7], [-2, -7, -3, -6, -3, 5, -2, -2, 3], [-10, 3, 6, -7, -8, -5, 2, 4, 0], [13, -2, -7, -3, -4, -6, 16, 5, 2], [-2, 1, 12, 2, 5, 6, 1, -1, 1], [0, -1, -2, -6, -3, -7, 3, 5, -2], [8, -4, 2, -5, 1, -1, 10, 2, 0], [-8, 3, 5, 0, 3, -2, 7, -5, -3], [2, 4, 14, 1, -1, 2, 14, -1, 1], [-6, -1, 0, 9, 0, 10, -11, -1, -2], [6, -7, -24, -9, -4, -2, -8, 2, -1], [-2, 6, 8, 10, -2, 9, -10, 0, 6], [6, 4, -4, 9, 5, 2, -14, 0, 4], [-20, -1, -12, 8, 3, 10, -13, -3, -2], [4, -1, 15, -2, 7, -6, 9, -1, 2], [-2, 3, 4, -4, -2, -4, 1, 1, 0], [8, -10, -1, 6, -1, 3, 1, 3, 8], [-2, 2, -2, -6, 9, -8, 7, 0, 0], [16, 2, 0, 5, 2, 0, -10, -5, -1], [-8, 3, 6, 0, -1, -5, -9, 1, 2], [0, -2, 12, -1, -3, 8, 0, 2, 6], [-5, -1, 5, 4, -1, -4, 15, 4, 0], [6, -2, -4, -8, -9, 3, -4, -1, -5], [-2, 3, 6, 6, -2, 10, -5, -5, 2], [6, 2, 4, -11, 0, -9, 13, 3, -3], [-12, 0, -16, -11, -8, -7, 4, 8, 4], [10, -2, -2, 2, -7, -2, -15, -7, 0], [-14, 11, 4, 1, -5, 0, -8, 2, 4], [2, -10, 0, 10, 5, 4, 7, -1, -1], [16, -4, -12, -9, -6, -12, 9, 4, -1], [4, -7, 6, -5, 0, 3, 16, -3, 2], [4, 4, 2, 4, 5, -1, 9, 0, 7], [20, 5, 2, 4, 0, 0, 2, -3, 5], [12, -3, -4, -2, 0, 7, -6, 4, 1], [-4, 6, -3, 5, 0, 4, 4, -4, -6], [12, -4, 9, -3, -10, 0, -3, -1, -5], [-4, 5, -6, 4, 4, 5, -19, -7, 5], [1, 7, 7, 0, 0, 0, 5, -8, -4], [-4, 1, -2, -3, 0, 5, 8, 4, -6], [-6, 6, -2, 2, 9, -9, -1, 5, 4], [2, -2, -11, 7, -1, 11, -14, -12, -3], [16, -7, 6, -7, 1, -6, 20, 0, -1], [26, -5, -6, 5, 1, -1, 0, 1, 1], [18, -10, 10, 6, 6, 3, 3, -5, -9], [4, -10, -18, -4, -3, -3, -5, -5, 2], [-4, 4, -2, -2, 4, 2, 10, 4, 3], [-4, 1, -4, 0, 5, -9, 2, 10, 5], [-5, 2, -1, 13, 7, 9, -20, -7, 2], [-22, -7, -8, 2, 8, 8, -12, -6, -2], [-8, 5, -2, 3, 0, 7, -8, -2, -3], [6, -2, 8, -1, 7, 6, -5, -1, 5], [0, -9, 6, 0, 3, 3, -1, 3, -5], [-4, 4, 16, -3, -3, 6, 5, 3, 6], [-12, -1, -13, -14, -3, -13, -4, -2, -9], [-8, -2, 8, -3, -5, -6, -6, 11, 3], [26, -5, 0, -7, -2, 4, 13, 13, 5], [-2, 8, 8, -6, -7, -1, -7, 3, 2], [-8, 2, -3, -4, -5, 2, 4, 4, -6], [10, 8, 16, 4, -5, 11, 15, 1, 6], [-8, 7, 12, -11, 8, -5, 12, -2, 0], [4, -6, -8, 6, 10, -10, -12, -3, 2], [-4, 13, 6, 3, 0, -7, 3, -9, -9], [-4, -9, -4, 7, 7, -7, -15, -13, -9], [0, 2, 6, 9, -6, 13, -12, 7, 10], [0, 0, 0, -8, 1, -10, 14, 1, 2], [0, -2, -1, 5, 1, 9, -14, 10, 9], [4, -1, -18, -1, -2, -6, -12, -6, 2], [-1, -9, -7, -4, 2, -6, -4, 1, -5], [6, -3, 4, 8, 2, 7, -9, -1, -5], [12, -6, 10, 2, 11, -11, -2, -2, 2], [-2, -1, -10, 4, 3, -5, 2, -6, 0], [-3, 14, 13, 0, -4, 1, 2, 3, 5], [2, -4, -6, -4, -6, -1, 10, 0, -8], [-8, -11, -7, -4, -4, 6, -11, 5, 13], [-4, -12, -12, 0, -2, -5, 0, 6, -5], [4, 6, 7, 13, 4, 13, -2, -6, -3], [-6, -3, -2, 3, 2, 10, 4, -6, -6], [-24, 8, -8, 15, 1, 6, -19, 3, 7], [-2, 6, 2, 6, 2, -6, 2, -7, -6], [26, 13, 10, 3, -2, -7, 6, -6, -4], [28, -4, 8, -6, -4, 2, 38, 2, 0], [-6, 12, -1, 14, 9, 10, -24, -8, 1], [31, -5, 13, -8, -10, 1, 4, 3, -5], [-14, 2, 6, 7, -9, 7, -5, -5, 7], [10, -8, -4, 0, -12, 9, -13, 0, -1], [-8, 1, 12, 10, -1, -1, 6, 4, 7], [-2, -4, 14, -5, -4, 3, 12, -7, -3], [12, -14, -18, -10, -12, 8, -8, 4, 1], [-10, -7, -8, 16, 5, 5, 5, -3, -9], [-14, 4, -12, 3, -6, -2, -4, 10, -5], [2, -9, -10, -7, -6, 8, 0, -4, 1], [-18, 3, -20, -8, -12, -1, 1, 10, -1], [4, -1, 7, -1, -4, 10, -8, -6, -4], [3, -2, 1, -6, 1, 3, 14, -1, 9], [3, 7, 1, -7, -2, -18, 17, 8, -5], [-4, 8, 2, -7, -3, 3, 1, 9, 2], [-2, 8, -20, 0, -1, -11, -9, 4, -7], [14, -6, -2, -10, -13, 8, -2, -2, 1], [-5, 7, -3, 5, 0, 12, -16, -1, 4], [22, -2, -1, -17, -20, 3, 17, 3, 5], [0, -9, -2, 0, -12, 5, -1, 7, 3], [3, -8, -7, 1, 4, 9, -11, 8, 3], [-4, 12, -6, -6, -8, -5, 1, 7, 7], [-6, 1, 8, 1, -7, 1, 11, 5, 5], [7, 10, 11, 3, -8, 18, 5, -4, 4], [8, 3, -14, -1, 0, 10, -9, -7, -8], [25, 3, 21, -1, 3, -9, 34, -1, -7], [-3, 1, 19, 3, 1, 0, -10, -1, -1], [8, 3, -10, 4, -2, -8, -2, 0, -9], [6, 7, 32, -3, -2, -5, -3, -3, 2], [-14, 9, 0, 3, -4, -4, 10, 6, 1], [24, 2, -3, -9, 2, -7, 10, 2, -3], [14, -19, -8, -8, -5, 3, 18, -6, -5], [-6, 8, 20, -7, 7, -9, -1, -4, 4], [12, -8, -10, 2, 0, -6, 14, 0, -3], [7, 3, -5, 17, 6, 12, -11, -14, -8], [4, 11, 16, 9, 7, -5, 15, 2, -11], [-16, -1, -24, -3, 0, -2, -26, 0, 6], [-15, 4, 1, -7, 1, 3, -1, 2, -4], [-14, 9, 18, 9, 2, -6, 2, 4, 0], [6, -6, 24, 3, 7, 3, -8, -10, -13], [16, 4, -19, -3, -5, 15, -16, -2, -4], [-4, 8, -12, 11, -5, 16, -23, -9, 8], [16, -5, 10, -16, 3, -15, 2, -2, -2], [-2, 8, 16, -1, -2, -5, 7, -7, -12], [16, -5, 2, 7, 2, 10, -1, -5, 3], [12, -6, 2, -6, -3, 3, 23, 12, 3], [2, -8, 8, -11, 7, -18, 14, -4, -14], [-4, 5, -6, -8, -3, -5, -8, -6, 3], [-19, 0, -31, -1, -1, -3, -1, 6, 6], [2, -5, 12, 1, 10, -6, -15, -3, -12], [12, -1, 14, -10, -10, -8, 14, 6, -2], [-18, 7, 1, -8, -1, -2, 4, -2, -3], [33, -1, -5, 8, 3, 1, 8, -7, 0], [-6, -1, -10, -12, -9, -1, 13, 9, -4], [16, -4, -6, -9, -14, 16, 8, 4, 5], [-10, 1, 4, 1, -3, 6, -20, -8, 6], [-8, -2, 0, 16, 0, 13, -11, 3, 8], [16, 8, 4, 2, -4, -6, 14, 0, 10], [12, 1, 34, 5, 8, 3, 5, -6, -4], [30, -1, 18, -19, -17, -8, 25, 8, -7], [6, 15, 18, 1, 3, 8, 21, -3, 5], [-6, -1, -4, 12, 4, -8, -5, -3, -2], [-32, -1, -22, 2, 5, -3, -9, -13, -9], [-28, 3, 2, 9, 11, -10, -16, -2, -5], [0, 10, -6, 6, 1, -12, 2, -12, 0], [24, -4, -10, 1, 2, 13, -6, -3, 2], [-27, -10, -25, -1, -6, 3, -25, 4, -1], [-6, 3, 14, -8, 5, -17, 12, 14, -5], [-8, -12, -25, 7, -2, 1, -9, 9, -2], [22, 2, 13, 4, 6, -5, -6, -6, 2], [-40, 13, -16, 14, 8, 4, -26, 6, 8], [-28, -8, -2, 9, 0, 11, -19, 3, -5], [-24, -3, -20, 5, 1, 7, -20, -10, -2], [16, -15, -17, -12, 3, -12, 1, 7, -6], [27, -18, -3, 10, -7, 11, 7, -8, 3], [-2, 9, -12, -3, 3, -6, 0, -8, 1], [-14, -12, -18, -9, -6, -1, -7, -3, -7], [-5, -8, -5, -7, -2, 5, 24, 1, 5], [2, -1, -13, -2, 13, -16, -4, 6, -3], [6, 4, 24, -3, -1, 1, 11, 4, -4], [-4, 9, 16, -4, 2, -2, -15, -1, 1], [14, 9, 15, 9, 8, 1, -14, 4, 4], [8, -12, -6, -2, -1, -3, 12, 20, 12], [-28, 8, -2, 4, 13, -2, -3, -11, -1], [13, -2, -7, -6, -11, 1, 12, 9, 9], [-4, 10, 24, 4, 0, -3, -6, -4, 7], [12, -8, 4, -8, 7, -16, 13, 13, 2], [10, 10, 17, 2, 11, -1, 1, -1, 1], [-24, 1, 8, -1, -2, -12, 7, -7, -3], [16, -7, 10, -1, 5, -13, 10, 5, 4], [-14, 14, 26, -2, 6, -6, -8, -10, 1], [-2, 8, 8, 18, 14, 26, -15, -9, 7], [-2, 0, -27, -3, -6, 2, 13, 5, 7], [-19, 15, 15, 20, 16, -5, -12, -15, 1], [10, 0, 4, -11, -7, 8, 11, -7, 6], [-26, 8, 6, 5, 0, 8, -4, 8, 2], [6, -15, 10, -2, -4, 1, 1, 3, 10], [20, -13, 18, -2, 10, -6, 18, -6, -13], [20, -4, 14, 5, -7, 21, 11, -10, -2], [-2, 20, -2, -5, 2, -9, 6, 12, 7], [-8, -15, 4, -3, 12, -5, -1, -5, -11], [5, 6, 3, -4, 3, -18, 18, -5, -15], [12, 4, 1, -16, -3, 1, 35, 19, 11], [14, 6, -12, -3, -9, -3, -10, 2, 7], [-16, 15, 3, -1, -6, -1, 15, 15, 2], [14, -6, 22, 3, -4, -3, 21, -2, -5], [22, -1, 22, -15, 3, -11, 32, 12, 9], [4, -5, 1, 12, -8, 11, -12, 12, -2], [4, 4, 30, 15, 6, 2, 21, 5, 9], [0, 20, 26, 13, 18, 6, -9, -9, 5], [-20, 7, -7, 4, 7, 2, 18, -2, 11], [-22, 8, 18, 16, 5, -4, -3, -7, -1], [-4, 12, 13, -4, -9, 6, -7, -9, -1], [-6, 9, 2, -10, 6, 0, 18, 6, 9], [-8, -11, -14, -6, 11, -18, -3, 17, 3], [10, 9, 11, 7, -2, 9, 20, -4, 3], [6, -8, 12, -23, 4, -19, 36, 16, -3], [28, -12, 10, 4, 11, 3, 7, 3, 3], [4, 9, 14, -22, -2, -23, 15, 17, -4], [-12, -1, -22, 5, 6, -15, 10, 16, 7], [7, 0, -5, 15, 5, 1, -20, -11, -7], [-2, 7, 4, 1, -6, 13, -4, 14, -1], [-5, 16, 27, 7, 9, -1, -1, 0, -1], [-16, -16, -18, -10, -9, 6, 0, 6, 3], [-1, 9, -1, -9, -1, 8, 8, 21, 15], [4, -15, -24, -11, 0, 5, -12, -8, -9], [-6, -10, -23, -19, 4, -6, -8, -4, -7], [-7, 10, 23, 19, 8, -1, 7, -12, 9], [-18, -12, -4, 9, 3, 10, -7, 3, 1], [-28, -12, -16, -10, -5, -4, 6, -6, 1], [4, -11, -24, 4, 2, -2, -20, 5, 10], [8, -11, -24, 7, 8, 2, -24, -10, 2], [-26, 8, -6, -10, 16, -13, -11, 1, 0], [-25, -17, -23, -12, 2, 0, 1, 6, 3], [-32, 5, -4, -7, -5, -12, -6, 11, 13], [-4, 6, 22, 11, 0, 3, 23, -1, 11], [-14, 4, -26, 7, -1, 18, -28, -4, -6], [6, 1, -6, 1, -1, 15, 3, -10, -1], [-12, 5, 26, -8, 7, 0, 18, -2, -8], [-9, 9, -15, 4, -6, 13, -15, 4, 6], [6, 3, 4, -5, -4, 13, 17, 11, 5], [28, 11, 18, -1, -4, 5, 9, -9, -4], [-14, 1, -26, 12, 0, 13, -17, -9, -7], [-8, 1, -10, 11, 11, 5, -1, -1, 4], [26, 14, 7, -16, -6, -20, 17, 1, -7], [4, 20, 14, 9, 7, 9, -15, 0, 10], [2, 16, 19, -2, 3, 7, -24, -14, -5], [-4, -1, -6, -1, 4, -25, 1, -7, -15], [-10, -14, -24, -10, 0, -10, 16, -10, -9], [-10, 4, 0, 1, 0, -1, -6, -16, -15], [20, -4, -12, -2, 6, 4, -2, 8, 4], [23, -10, 11, -26, -8, 0, 14, 7, 4], [28, 3, 11, -13, 5, -17, 12, -4, 6], [-12, 8, 2, 17, 12, -16, 5, -7, -3], [14, -12, -4, 6, 8, 5, 0, -8, -6], [9, 25, 11, 3, -16, 4, 3, 8, 10], [-18, 1, 7, 14, 9, 5, -4, -14, -2], [5, -9, -9, -18, -5, 2, 24, -5, -6], [34, -18, -10, -13, -22, 4, 7, 5, -2], [-14, -3, -42, -16, -10, -4, -22, -7, -12], [-18, 13, 18, 5, 5, 3, -5, -5, 3], [16, -3, 9, -12, -1, 3, 17, 23, 11], [-14, 17, 6, 3, -6, 8, 27, -7, -6], [-8, 4, 28, 5, -2, 2, -3, 1, 9], [7, -22, -27, -4, -10, -3, -15, 6, -8], [32, 14, 4, -3, -20, 0, -2, 4, -1], [-14, -21, -3, -14, 11, -7, 4, 4, -5], [15, -7, 5, -10, 4, -11, -6, -11, -16], [32, -10, 12, -15, -10, 2, 33, 1, -1], [-35, -13, -17, 2, 12, -5, -31, -14, -11], [11, 6, 19, 15, 4, 9, -17, -16, 0], [-28, -8, -18, 10, -3, 17, -12, -14, 0], [-16, -7, -4, -11, 5, 5, -22, -12, -16], [20, -11, -9, 13, -12, 14, -7, 3, 4], [-10, 17, 4, -9, 10, -9, 16, 4, -1], [14, 6, 9, -4, -9, 9, -24, 0, -4], [26, -1, -14, -7, -11, -11, 13, 9, 4], [-20, -20, -22, 1, 6, 0, -24, -8, -9], [24, -21, 4, -14, -5, -1, 18, -8, -15], [-26, 18, 2, 6, 3, 1, -19, -11, 5], [-2, 11, -2, 0, -9, -13, 4, 1, -2], [-21, 3, 3, -6, -2, -20, -1, 2, -5], [-16, 4, -8, 18, 6, 4, -1, 5, 7], [-46, -5, -21, -2, 14, -10, -16, -4, 2], [2, -16, -30, 1, -8, 13, -11, -7, -5], [-14, 3, 6, -1, 0, 2, -3, 11, -6], [2, 23, 26, 6, 5, 22, -3, -1, 14], [34, -9, 24, 16, 17, 16, 0, -7, -1], [22, -8, 6, -4, 6, -7, -6, -12, -10], [20, -6, 13, -18, -10, -10, 7, 17, 5], [-22, 1, -14, 11, 6, -5, 1, -1, -7], [10, -11, 10, 5, -8, -4, -13, -5, -7], [-27, 23, 7, -3, -2, -5, -10, 5, 14], [-2, -1, 10, -1, 4, 4, 14, 5, 5], [-20, 19, -27, 0, 7, -19, 8, 4, 8], [-4, -8, 25, 5, 5, 5, 15, 5, 12], [-44, 8, -14, -8, -2, -10, -35, -8, 1], [12, -8, -18, 3, 7, -4, -16, -16, -6], [-6, 0, 25, -4, -8, -1, 7, 1, 7], [-30, 1, -22, 6, 6, 2, -19, 5, 4], [-38, 16, 4, -4, 0, -13, -17, 1, -6], [-14, -2, 2, 6, 15, 11, 5, -7, 10], [26, 2, 10, 13, -3, 2, 9, 6, 3], [4, -16, 12, 1, 0, 5, -2, 12, -3], [-4, -2, -6, -21, 7, -1, -12, 12, 7], [-10, -23, 6, -6, 7, -16, 26, 9, 2], [2, 7, 46, 13, -1, 19, 13, -4, 5], [20, -17, 22, 19, 1, 15, -2, -16, -1], [38, -8, 8, -17, 5, -21, 44, 2, -11], [-14, -1, 26, 10, 12, 22, -11, -13, 4], [32, -8, 4, 6, 16, 5, 3, -4, 0], [-10, 25, 2, 22, 2, -13, -9, -5, -8], [-23, -2, -17, -24, 4, -2, -23, 14, 6], [-30, 14, -12, 22, -2, 11, -10, -6, -6], [26, -15, 12, -20, -8, -18, 35, 24, -1], [16, 7, 8, -4, 16, -7, 6, -17, -12], [16, -14, 5, 5, 0, 13, -5, 3, 11], [-20, 10, -6, -7, 1, -1, -6, -4, 12], [6, -1, 8, -3, -10, 28, -11, 9, 17], [10, -4, 17, 16, 1, 7, 7, -9, -4], [22, 0, 12, 0, 8, 9, -6, -20, 5], [2, 3, -14, 4, 4, -12, -9, -4, 8], [-4, -33, -28, -2, 1, -7, -12, -8, -15], [-2, 14, -2, -6, -8, 5, -2, 14, 17], [-10, 5, 20, 1, 9, -18, 14, 14, -1], [-1, -8, -39, -16, 3, -9, -13, -12, -15], [-2, -3, -34, 20, 9, 7, -13, -16, -4], [4, 15, 12, -2, -8, -10, 31, -1, -16], [-4, 17, 6, -7, -11, 0, 30, 24, 9], [26, 12, -3, -13, -13, -17, -1, -5, -10], [-6, -7, -19, -4, -11, 7, 6, 12, 6], [-22, 6, -14, -8, 14, -7, -1, 3, 9], [14, 6, 26, 5, 3, -23, 4, -18, -13], [-13, 4, -13, -23, -19, -14, -6, 5, 0], [28, -14, 6, 7, 2, -8, 19, -1, 3], [0, 1, 30, 4, 10, -1, 12, -7, -11], [33, -10, 19, -20, -4, -26, 40, 9, -3], [2, -3, -32, -10, -2, -15, -3, -9, -11], [-36, 34, 4, 21, 6, 15, -37, -11, 19], [14, -24, -6, 4, 10, -6, -8, -7, -20], [18, -24, -16, -7, 1, 1, 13, 5, -3], [-6, -8, 8, -5, -9, -8, 0, 0, -4], [-10, 8, 11, -3, -2, 5, 2, -4, 13], [-2, 0, 26, 25, 9, 13, 17, -5, 1], [32, -11, 14, -4, -9, 1, 17, -5, -13]]
